/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */

/* filesystems.h - Private header file to be included by filesystems
   of the GNOME Virtual File System.

   Copyright (C) 2003 Free Software Foundation

   The Gnome Library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public License as
   published by the Free Software Foundation; either version 2 of the
   License, or (at your option) any later version.

   The Gnome Library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public
   License along with the Gnome Library; see the file COPYING.LIB.  If not,
   write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.

   Author: Jan Kratochvil <project-captive@jankratochvil.net> */

#ifndef GNOME_VFS_FILESYSTEM_ENTRY_H
#define GNOME_VFS_FILESYSTEM_ENTRY_H

#include <libgnomevfs/gnome-vfs-method.h>
#include <glib.h>

#define GNOME_VFS_MODULE_INIT_FUNC      vfs_module_init
#define GNOME_VFS_MODULE_TRANSFORM_FUNC vfs_module_transform
#define GNOME_VFS_MODULE_SHUTDOWN_FUNC  vfs_module_shutdown

#define GNOME_VFS_MODULE_INIT      G_STRINGIFY(GNOME_VFS_MODULE_INIT_FUNC)
#define GNOME_VFS_MODULE_TRANSFORM G_STRINGIFY(GNOME_VFS_MODULE_TRANSFORM_FUNC)
#define GNOME_VFS_MODULE_SHUTDOWN  G_STRINGIFY(GNOME_VFS_MODULE_SHUTDOWN_FUNC)

typedef struct _GnomeVFSIncludedFilesystem GnomeVFSIncludedFilesystem;
struct _GnomeVFSIncludedFilesystem {
	const gchar               *filesystem_name;
	const gchar               *filesystem_args;
	gboolean                   run_in_daemon;
	GnomeVFSMethodInitFunc     init_function;
	GnomeVFSTransformInitFunc  transform_function;
	GnomeVFSMethodShutdownFunc shutdown_function;
};

#define FILESYSTEM_ENTRY_PREFIXED_ARG(filesystem,func) _gnome_vfs_ ## filesystem ## _ ## func
#define FILESYSTEM_ENTRY_PREFIXED(filesystem,func) FILESYSTEM_ENTRY_PREFIXED_ARG(filesystem,func)
#define FILESYSTEM_ENTRY_RAW_ARG(filesystem,func) func
#define FILESYSTEM_ENTRY_RAW(filesystem,func) FILESYSTEM_ENTRY_RAW_ARG(filesystem,func)

void gnome_vfs_register_included_filesystem (const GnomeVFSIncludedFilesystem *included_filesystem);

#endif /* GNOME_VFS_FILESYSTEM_ENTRY_H */
